@@ -1,4 +1,5 @@
 from os import makedirs, system, path, stat
+import time
 import pathlib
 from semver import VersionInfo
 from cement import Controller, ex
@@ -6,7 +7,7 @@ from ..core.config import load_config
 from ..core.utils import create_boilerplate, render_boilerplate, get_plugin_info, get_plugin_path, show_schema
 from ..core.tech_local import TestLocal
 from ..core.message_log import Log
-from ..core.AWS.s3 import S3
+from ..core.aws_s3 import S3
 
 
 class CrawlerBase(Controller):
@@ -168,10 +169,10 @@ class Crawler(Controller):
         ]
     )
     def deploy(self):
-        plugin_name = self.app.pargs.plugin_name
-
+        input_plugin_name = self.app.pargs.plugin_name
         deploy_message = self.app.pargs.message
-        if plugin_name is None:
+
+        if input_plugin_name is None:
             self.app.log.error(
                 "cannot deploy without service code")
             return False
@@ -188,77 +189,94 @@ class Crawler(Controller):
         major_flag = self.app.pargs.major_flag
         minor_flag = self.app.pargs.minor_flag
 
-        plugin_dir_path = get_plugin_path(plugin_name, all_types=True)
+        plugin_names = False
+        if(',' in input_plugin_name):
+            plugin_names = input_plugin_name.split(',')
 
-        if(plugin_dir_path):
-            system(
-                f"""cd {plugin_dir_path} && cd .. && git pull origin master""")
+        if(plugin_names == False):
+            plugin_names = []
+            plugin_names.append(input_plugin_name)
 
-            plugin_info = get_plugin_info(plugin_dir_path)
-            version_path = '{}/.version'.format(plugin_dir_path)
-            if(path.exists(version_path)):
-                with open(version_path, 'r') as f:
-                    version_info = VersionInfo.parse(f.read())
-                    if(major_flag):
-                        version_info = version_info.next_version(part='major')
-                    elif(minor_flag):
-                        version_info = version_info.next_version(part='minor')
-                    else:
-                        version_info = version_info.bump_patch()
+        for plugin_name in plugin_names:
+            print(f'Initiating Deplyment: {plugin_name} ')
 
-                    version_info = str(version_info)
-                    with open(version_path, 'w') as w:
-                        w.write(version_info)
+            plugin_name = plugin_name.strip()
 
-                self.app.log.info(
-                    "[{}] [{}] {}".format(deploy_type, version_info, deploy_message))
+            plugin_dir_path = get_plugin_path(plugin_name, all_types=True)
+
+            if(plugin_dir_path):
+                system(
+                    f"""cd {plugin_dir_path} && cd .. && git pull origin master""")
+
+                plugin_info = get_plugin_info(plugin_dir_path)
+                version_path = '{}/.version'.format(plugin_dir_path)
+                if(path.exists(version_path)):
+                    with open(version_path, 'r') as f:
+                        version_info = VersionInfo.parse(f.read())
+                        if(major_flag):
+                            version_info = version_info.next_version(
+                                part='major')
+                        elif(minor_flag):
+                            version_info = version_info.next_version(
+                                part='minor')
+                        else:
+                            version_info = version_info.bump_patch()
+
+                        version_info = str(version_info)
+                        with open(version_path, 'w') as w:
+                            w.write(version_info)
+
+                    self.app.log.info(
+                        "[{}] [{}] {}".format(deploy_type, version_info, deploy_message))
+                else:
+                    with open(version_path, 'w') as f:
+                        if(major_flag):
+                            version_info = "1.0.0"
+                        elif (minor_flag):
+                            version_info = "0.1.0"
+                        else:
+                            version_info = "0.0.1"
+
+                        f.write(version_info)
+
+                    self.app.log.info(
+                        "[{}] [{}] {}".format(deploy_type, version_info, deploy_message))
+
+                command = """
+                cd {} &&
+                cd .. &&
+                git add {}/ &&
+                git commit -m "[{}] [{}] {}" &&
+                git push origin master
+                """.format(plugin_dir_path, plugin_name, deploy_type, version_info, deploy_message)
+
+                show_schema(plugin_dir_path)
+
+                system(command)
+                # sleep for 2 second to make it look real deployment
+                time.sleep(2)
+                try:
+                    app_url = f'https://appnext.grepsr.com/projects/{plugin_info["pid"]}'
+                    self.app.log.info(f"App Url: {app_url}")
+                    self.app.log.info(
+                        f"Plugin: {plugin_name} deployed successfully")
+                except:
+                    self.app.log.warning(
+                        f"Cannot find pid in plugin, please find the project's url manually")
+                    self.app.log.info(
+                        f"Plugin: {plugin_name} deployed successfully")
             else:
-                with open(version_path, 'w') as f:
-                    if(major_flag):
-                        version_info = "1.0.0"
-                    elif (minor_flag):
-                        version_info = "0.1.0"
-                    else:
-                        version_info = "0.0.1"
-
-                    f.write(version_info)
-
-                self.app.log.info(
-                    "[{}] [{}] {}".format(deploy_type, version_info, deploy_message))
-
-            command = """
-            cd {} &&
-            cd .. &&
-            git add {}/ &&
-            git commit -m "[{}] [{}] {}" &&
-            git push origin master
-            """.format(plugin_dir_path, plugin_name, deploy_type, version_info, deploy_message)
-
-            show_schema(plugin_dir_path)
-
-            system(command)
-            try:
-                app_url = f'https://appnext.grepsr.com/projects/{plugin_info["pid"]}'
-                self.app.log.info(f"App Url: {app_url}")
-                self.app.log.info(
-                    f"Plugin: {plugin_name} deployed successfully")
-            except:
-                self.app.log.warning(
-                    f"Cannot find pid in plugin, please find the project's url manually")
-                self.app.log.info(
-                    f"Plugin: {plugin_name} deployed successfully")
-        else:
-            self.app.log.error(f'plugin: {plugin_name} was not found')
+                self.app.log.error(f'plugin: {plugin_name} was not found')
 
     @ex(
         help="update base_crawler packages",
         arguments=[
-            (['-b'], {
+            (['-s'], {
                 "help": "name of the base crawler you want to use",
                 "action": "store",
                 "dest": "base_plugin_name"
             }),
-            (['-s'], {
+            (['-t'], {
                 "help": "name of target crawler that you want to use",
                 "action": "store",
                 "dest": "plugin_name"
@@ -266,38 +284,55 @@ class Crawler(Controller):
         ]
     )
     def use_basecrawler(self):
+
         s3 = S3()
 
+        version = None
         base_plugin_name = self.app.pargs.base_plugin_name
+        target_plugin_name = self.app.pargs.plugin_name
+
+        if(base_plugin_name is None or target_plugin_name is None):
+            Log.error(
+                "Please Enter base crawler and target cralwers.\nUse gcli crawler use-basecrawler -h for more information")
+            return
+
         if('-' in base_plugin_name):
             version = base_plugin_name.split('-')[1]
             base_plugin_name = base_plugin_name.split('-')[0]
 
+        # to check if there is a base-plugin in thier gcli settings ...
         base_plugin_dir_path = get_plugin_path(
             base_plugin_name, type='php')
-        target_plugin_name = self.app.pargs.plugin_name
+
         target_plugin_path = get_plugin_path(
             target_plugin_name, type='php'
         )
 
-        if(base_plugin_dir_path):
+        if(version is None and base_plugin_dir_path):
             f = open(f"{base_plugin_dir_path}/.version", mode='r')
             version = f.read()
             f.close()
 
+        if(version is None):
+            Log.error(
+                "Please Specify the version of base crawler that you want to use")
+            return
+
+        if(target_plugin_path):
             Log.info(
                 f'Getting Secure Url of target plugin: {base_plugin_name}, {version}')
 
             presigned_url = s3.get_secure_url(bucket='crawler-plugins',
                                               filename=f'php/vortex-plugins-services-base/{base_plugin_name}/{base_plugin_name}-{version}.tar.gz')
-            if(target_plugin_path):
-                data = {
-                    'presigned_url': presigned_url,
-                    'plugin_name': base_plugin_name,
-                    'version': version
-                }
+            data = {
+                'presigned_url': presigned_url,
+                'plugin_name': base_plugin_name,
+                'version': version
+            }
 
-                render_boilerplate(boilerplate='composer.jinja2', data=data,
-                                   destination_path=target_plugin_path + '/composer.json')
-                system(
-                    f""" cd {target_plugin_path} &&  composer install""")
\ No newline at end of file
+            render_boilerplate(boilerplate='composer.jinja2', data=data,
+                               destination_path=target_plugin_path + '/composer.json')
+            system(
+                f""" cd {target_plugin_path} &&  composer install""")
+        else:
+            Log.error(f"Target plugin: {target_plugin_name} not found")
\ No newline at end of file
